/*
 *
 *           MULti Core Operating System - Tiny / Multilayer Kernel
 *                      Device header for RA6 AGT
 *
 *           Copyright (c) 2025 SPIRAL-TECH Co.,ltd All Rights Reserved.
 *
 *  File name       dv_ra6_agt.h
 *
 *  Feb/02/2025     Created.
 *
 */

#ifndef _DV_RA6_AGT_H_
#define _DV_RA6_AGT_H_
#ifdef __cplusplus
extern "C" {
#endif

/* Base Address */

#if defined(_DV_RA6M5_H_) || defined(_DV_RA4M3_H_)
#define AGT0_BASE       0x400E8000      /* AGT0 Base address */
#define AGT1_BASE       0x400E8100      /* AGT1 Base address */
#define AGT2_BASE       0x400E8200      /* AGT2 Base address */
#define AGT3_BASE       0x400E8300      /* AGT3 Base address */
#define AGT4_BASE       0x400E8400      /* AGT4 Base address */
#define AGT5_BASE       0x400E8500      /* AGT5 Base address */

#elif defined(_DV_RA4M3_H_)
#define AGT0_BASE       0x400E8000      /* AGT0 Base address */
#define AGT1_BASE       0x400E8100      /* AGT1 Base address */

#else
#error "I/O definition file is undefined."
#endif


/* Evento number */

#if defined(_DV_RA6M5_H_) || defined(_DV_RA4M3_H_)
#define EVENT_AGT0_BASE         0x040
#define EVENT_AGT1_BASE         0x043
#define EVENT_AGT2_BASE         0x046
#define EVENT_AGT3_BASE         0x049
#define EVENT_AGT4_BASE         0x04C
#define EVENT_AGT5_BASE         0x04F

#elif defined(_DV_RA4M3_H_)
#define EVENT_AGT0_BASE         0x040
#define EVENT_AGT1_BASE         0x043
#endif

#define EVENT_AGTI_OFFSET       0
#define EVENT_AGTCMAI_OFFSET    1
#define EVENT_AGTCMBI_OFFSET    2


/* registers */

typedef struct {
    UH  AGT;              /* AGT Counter register                              */
    UH  AGTCMA;           /* AGT Compare Match A register                      */
    UH  AGTCMB;           /* AGT Compare Match B register                      */
    UH  reserved;
    UB  AGTCR;            /* AGT Control register                              */
    UB  AGTMR1;           /* AGT Mode register 1                               */
    UB  AGTMR2;           /* AGT Mode register 2                               */
    UH  reserved1;
    UB  AGTIOC;           /* AGT I/O Control register                          */
    UB  AGTISR;           /* AGT Event Pin Select register                     */
    UB  AGTCMSR;          /* AGT Compare Match Function Select register        */
    UB  AGTIOSEL;         /* AGT Pin Select register                           */
} T_RA6_AGT; 


/* Port access structure */

#define REG_AGT0    (*(volatile T_RA6_AGT *)AGT0_BASE)
#define REG_AGT1    (*(volatile T_RA6_AGT *)AGT1_BASE)
#if defined(_DV_RA6M5_H_) || defined(_DV_RA4M3_H_)
#define REG_AGT2    (*(volatile T_RA6_AGT *)AGT2_BASE)
#define REG_AGT3    (*(volatile T_RA6_AGT *)AGT3_BASE)
#define REG_AGT4    (*(volatile T_RA6_AGT *)AGT4_BASE)
#define REG_AGT5    (*(volatile T_RA6_AGT *)AGT5_BASE)
#endif


#ifdef __cplusplus
}
#endif
#endif /* _DV_RA6_AGT_H_ */
