/*
 *
 *           MULti Core Operating System - Tiny / Multilayer Kernel
 *                      Device header for RA6 CPSCU
 *
 *           Copyright (c) 2025 SPIRAL-TECH Co.,ltd All Rights Reserved.
 *
 *  File name       dv_ra6_cpscu.h
 *
 *  Feb/02/2025     Created.
 *
 */

#ifndef _DV_RA6_CPSCU_H_
#define _DV_RA6_CPSCU_H_
#ifdef __cplusplus
extern "C" {
#endif

/* Base Address */

#if defined(_DV_RA6M5_H_) || defined(_DV_RA4M3_H_)
#define CPSCU_BASE      0x40008000      /* CPSCU Base address */
#else
#error "I/O definition file is undefined."
#endif


/* registers */

typedef struct {
    UW  CSAR;           /* Cache Security Attribution Register                 */
    UW  reserved[3];
    UW  SRAMSAR;        /* SRAM Security Attribution Register                  */
    UW  STBRAMSAR;      /* Standby RAM memory Security Attribution Register    */
    UW  reserved1[6];
    UW  DTCSAR;         /* DTC Controller Security Attribution Register        */
    UW  DMACSAR;        /* DMAC Controller Security Attribution Register       */
    UW  reserved2[2];
    UW  ICUSARA;        /* ICU Security Attribution Register A                 */
    UW  ICUSARB;        /* ICU Security Attribution Register B                 */
    UW  ICUSARC;        /* ICU Security Attribution Register C                 */
    UW  ICUSARD;        /* ICU Security Attribution Register D                 */
    UW  ICUSARE;        /* ICU Security Attribution Register E                 */
    UW  ICUSARF;        /* ICU Security Attribution Register F                 */
    UW  reserved3[6];
    UW  ICUSARG;        /* ICU Security Attribution Register G                 */
    UW  ICUSARH;        /* ICU Security Attribution Register H                 */
    UW  ICUSARI;        /* ICU Security Attribution Register I                 */
    UW  reserved4[33];
    UW  BUSSARA;        /* Bus Security Attribution Register A                 */
    UW  BUSSARB;        /* Bus Security Attribution Register B                 */
    UW  reserved5[10];
    UW  MMPUSARA;       /* Master MPU Security Attribution Register A          */
    UW  MMPUSARB;       /* Master MPU Security Attribution Register B          */
    UW  reserved6[26];
    UW  DMACCHSAR;      /* DMA channel Security Attribution Register           */
    UW  reserved7[3];
    UW  CPUDSAR;        /* CPU Debug Security Attribution Register             */
    UW  reserved8[147];
    UW  SRAMSABAR0;     /* SRAM Security Attribute Boundary Address Register 0 */
    UW  SRAMSABAR1;     /* SRAM Security Attribute Boundary Address Register 1 */
    UW  reserved9[126];
    UW  TEVTRCR;        /* Trusted Event Route Control Register                */
} T_RA6_CPSCU; 


/* Port access structure */

#define REG_CPSCU   (*(volatile T_RA6_CPSCU *)CPSCU_BASE)


#ifdef __cplusplus
}
#endif
#endif /* _DV_RA6_CPSCU_H_ */
