/*
 *
 *           MULti Core Operating System - Tiny / Multilayer Kernel
 *                      Device header for RA6 ICU
 *
 *           Copyright (c) 2025 SPIRAL-TECH Co.,ltd All Rights Reserved.
 *
 *  File name       dv_ra6_icu.h
 *
 *  Feb/02/2025     Created.
 *
 */

#ifndef _DV_RA6_ICU_H_
#define _DV_RA6_ICU_H_
#ifdef __cplusplus
extern "C" {
#endif

/* Base Address */

#define ICU_BASE        0x40006000      /* ICU Base address */
#if defined(_DV_RA6M5_H_)
#define EVENT_MAX     0x1DB
#elif defined(_DV_RA6M3_H_)
#define EVENT_MAX     0x1FF
#elif defined(_DV_RA4M3_H_)
#define EVENT_MAX     0x1DB
#else
#error "I/O definition file is undefined."
#endif


/* registers */

typedef struct {
    UB  IRQCR[16];      /* IRQ Control Register [0..15]                        */
    UW  reserved[60];
    UB  NMICR;          /* NMI Pin Interrupt Control Register                  */
    UB  reserved1;
    UH  reserved2;
    UW  reserved3[7];
    UH  NMIER;          /* Non-Maskable Interrupt Enable Register              */
    UH  reserved4;
    UW  reserved5[3];
    UH  NMICLR;         /* Non-Maskable Interrupt Status Clear Register        */
    UH  reserved6;
    UW  reserved7[3];
    UH  NMISR;          /* Non-Maskable Interrupt Status Register              */
    UH  reserved8;
    UW  reserved9[23];
    UW  WUPEN;          /* Wake Up Interrupt Enable Register                   */
    UW  WUPEN1;         /* Wake Up interrupt enable register 1                 */
    UW  reserved10[6];
    UB  IELEN;          /* ICU event Enable Register                           */
    UB  reserved11;
    UH  reserved12;
    UW  reserved13[15];
    UH  SELSR0;         /* Snooze Event Link Setting Register                  */
    UH  reserved14;
    UW  reserved15[31];
    UW  DELSR[8];       /* DMAC Event Link Setting Register                    */
    UW  reserved16[24];
    UW  IELSR[96];      /* ICU Event Link Setting Register [0..95]             */
} T_RA6_ICU; 


/* Port access structure */

#define REG_ICU     (*(volatile T_RA6_ICU *)ICU_BASE)


#ifdef __cplusplus
}
#endif
#endif /* _DV_RA6_ICU_H_ */
