/*
 *
 *           MULti Core Operating System - Tiny / Multilayer Kernel
 *                      Device header for RA6 PFS&PORT
 *
 *           Copyright (c) 2025 SPIRAL-TECH Co.,ltd All Rights Reserved.
 *
 *  File name       dv_ra6_pfs_port.h
 *
 *  Feb/02/2025     Created.
 *
 */

#ifndef _DV_RA6_PFS_PORT_H_
#define _DV_RA6_PFS_PORT_H_
#ifdef __cplusplus
extern "C" {
#endif

/* Base Address */

#if defined(_DV_RA6M5_H_)
#define PORT0_BASE      0x40080000      /* PORT0 Base address */
#define PORT1_BASE      0x40080020      /* PORT1 Base address */
#define PORT2_BASE      0x40080040      /* PORT2 Base address */
#define PORT3_BASE      0x40080060      /* PORT3 Base address */
#define PORT4_BASE      0x40080080      /* PORT4 Base address */
#define PORT5_BASE      0x400800A0      /* PORT5 Base address */
#define PORT6_BASE      0x400800C0      /* PORT6 Base address */
#define PORT7_BASE      0x400800E0      /* PORT7 Base address */
#define PORT8_BASE      0x40080100      /* PORT8 Base address */
#define PORT9_BASE      0x40080120      /* PORT9 Base address */
#define PORTA_BASE      0x40080140      /* PORTA Base address */
#define PORTB_BASE      0x40080160      /* PORTB Base address */

#define PFS0_BASE       0x40080800      /* PFS0 Base address */
#define PFS1_BASE       0x40080840      /* PFS1 Base address */
#define PFS2_BASE       0x40080880      /* PFS2 Base address */
#define PFS3_BASE       0x400808C0      /* PFS3 Base address */
#define PFS4_BASE       0x40080900      /* PFS4 Base address */
#define PFS5_BASE       0x40080940      /* PFS5 Base address */
#define PFS6_BASE       0x40080980      /* PFS6 Base address */
#define PFS7_BASE       0x400809C0      /* PFS7 Base address */
#define PFS8_BASE       0x40080A00      /* PFS8 Base address */
#define PFS9_BASE       0x40080A40      /* PFS9 Base address */
#define PFSA_BASE       0x40080A80      /* PFSA Base address */
#define PFSB_BASE       0x40080AC0      /* PFSB Base address */

#define SAR_BASE        0x40080D10      /* SAR Base address */

#define PFENET_BASE     0x40080D00      /* Ethernet and Write Protect address */
#define PWPR_BASE       0x40080D03      /* Write Protect for NonSecure address */
#define PWPRS_BASE      0x40080D05      /* Write Protect for Secure address */

#elif defined(_DV_RA6M3_H_)
#define PORT0_BASE      0x40040000      /* PORT0 Base address */
#define PORT1_BASE      0x40040020      /* PORT1 Base address */
#define PORT2_BASE      0x40040040      /* PORT2 Base address */
#define PORT3_BASE      0x40040060      /* PORT3 Base address */
#define PORT4_BASE      0x40040080      /* PORT4 Base address */
#define PORT5_BASE      0x400400A0      /* PORT5 Base address */
#define PORT6_BASE      0x400400C0      /* PORT6 Base address */
#define PORT7_BASE      0x400400E0      /* PORT7 Base address */
#define PORT8_BASE      0x40040100      /* PORT8 Base address */
#define PORT9_BASE      0x40040120      /* PORT9 Base address */
#define PORTA_BASE      0x40040140      /* PORTA Base address */
#define PORTB_BASE      0x40040160      /* PORTB Base address */

#define PFS0_BASE       0x40040800      /* PFS0 Base address */
#define PFS1_BASE       0x40040840      /* PFS1 Base address */
#define PFS2_BASE       0x40040880      /* PFS2 Base address */
#define PFS3_BASE       0x400408C0      /* PFS3 Base address */
#define PFS4_BASE       0x40040900      /* PFS4 Base address */
#define PFS5_BASE       0x40040940      /* PFS5 Base address */
#define PFS6_BASE       0x40040980      /* PFS6 Base address */
#define PFS7_BASE       0x400409C0      /* PFS7 Base address */
#define PFS8_BASE       0x40040A00      /* PFS8 Base address */
#define PFS9_BASE       0x40040A40      /* PFS9 Base address */
#define PFSA_BASE       0x40040A80      /* PFSA Base address */
#define PFSB_BASE       0x40040AC0      /* PFSB Base address */

#define PFENET_BASE     0x40040D00      /* Ethernet and Write Protect address */
#define PWPR_BASE       0x40040D03      /* Write Protect for NonSecure address */

#elif defined(_DV_RA4M3_H_)
#define PORT0_BASE      0x40080000      /* PORT0 Base address */
#define PORT1_BASE      0x40080020      /* PORT1 Base address */
#define PORT2_BASE      0x40080040      /* PORT2 Base address */
#define PORT3_BASE      0x40080060      /* PORT3 Base address */
#define PORT4_BASE      0x40080080      /* PORT4 Base address */
#define PORT5_BASE      0x400800A0      /* PORT5 Base address */
#define PORT6_BASE      0x400800C0      /* PORT6 Base address */
#define PORT7_BASE      0x400800E0      /* PORT7 Base address */
#define PORT8_BASE      0x40080100      /* PORT8 Base address */

#define PFS0_BASE       0x40080800      /* PFS0 Base address */
#define PFS1_BASE       0x40080840      /* PFS1 Base address */
#define PFS2_BASE       0x40080880      /* PFS2 Base address */
#define PFS3_BASE       0x400808C0      /* PFS3 Base address */
#define PFS4_BASE       0x40080900      /* PFS4 Base address */
#define PFS5_BASE       0x40080940      /* PFS5 Base address */
#define PFS6_BASE       0x40080980      /* PFS6 Base address */
#define PFS7_BASE       0x400809C0      /* PFS7 Base address */
#define PFS8_BASE       0x40080A00      /* PFS8 Base address */

#define SAR_BASE        0x40080D10      /* SAR Base address */

#define PWPR_BASE       0x40080D03      /* Write Protect for NonSecure address */
#define PWPRS_BASE      0x40080D05      /* Write Protect for Secure address */

#else
#error "I/O definition file is undefined."
#endif


/* registers */

typedef struct {
    union {
        UW    WORD;               /* Port Control Register 1                   */
        struct {
            UH    PODR;           /* Output data register                      */
            UH    PDR;            /* Data direction register                   */
        };
    } PCNTR1;
    union {
        UW    WORD;               /* Port Control Register 2                   */
        struct {
            UH    EIDR;           /* Event input data register                 */
            UH    PIDR;           /* Input data register                       */
        };
    } PCNTR2;
    union {
        UW    WORD;               /* Port Control Register 3                   */
        struct {
            UH    PORR;           /* Output set register                       */
            UH    POSR;           /* Output reset register                     */
        };
    } PCNTR3;
    union {
        UW    WORD;               /* Port Control Register 4                   */
        struct {
            UH    EORR;           /* Event output set register                 */
            UH    EOSR;           /* Event output reset register               */
        };
    } PCNTR4;
} T_RA6_PORT; 

typedef struct {
    union {
        UW    PnmPFS;             /* Port mn Pin Function Select register      */
        struct {
            UH    reserved1;
            UH    PnmPFS_HA;
        };
        struct {
            UB    reserved2[3];
            UB    PnmPFS_BY;
        };
    };
} T_RA6_PFS;

typedef struct {
    UH    PmSAR;                  /* Port Security Attribution register        */
} T_RA6_SAR; 


/* Port access structure */
#if defined(_DV_RA6M5_H_)
#define REG_PORT0   (*(volatile T_RA6_PORT *)PORT0_BASE)
#define REG_PORT1   (*(volatile T_RA6_PORT *)PORT1_BASE)
#define REG_PORT2   (*(volatile T_RA6_PORT *)PORT2_BASE)
#define REG_PORT3   (*(volatile T_RA6_PORT *)PORT3_BASE)
#define REG_PORT4   (*(volatile T_RA6_PORT *)PORT4_BASE)
#define REG_PORT5   (*(volatile T_RA6_PORT *)PORT5_BASE)
#define REG_PORT6   (*(volatile T_RA6_PORT *)PORT6_BASE)
#define REG_PORT7   (*(volatile T_RA6_PORT *)PORT7_BASE)
#define REG_PORT8   (*(volatile T_RA6_PORT *)PORT8_BASE)
#define REG_PORT9   (*(volatile T_RA6_PORT *)PORT9_BASE)
#define REG_PORTA   (*(volatile T_RA6_PORT *)PORTA_BASE)
#define REG_PORTB   (*(volatile T_RA6_PORT *)PORTB_BASE)

#define REG_PFS0    ( (volatile T_RA6_PFS *)PFS0_BASE)
#define REG_PFS1    ( (volatile T_RA6_PFS *)PFS1_BASE)
#define REG_PFS2    ( (volatile T_RA6_PFS *)PFS2_BASE)
#define REG_PFS3    ( (volatile T_RA6_PFS *)PFS3_BASE)
#define REG_PFS4    ( (volatile T_RA6_PFS *)PFS4_BASE)
#define REG_PFS5    ( (volatile T_RA6_PFS *)PFS5_BASE)
#define REG_PFS6    ( (volatile T_RA6_PFS *)PFS6_BASE)
#define REG_PFS7    ( (volatile T_RA6_PFS *)PFS7_BASE)
#define REG_PFS8    ( (volatile T_RA6_PFS *)PFS8_BASE)
#define REG_PFS9    ( (volatile T_RA6_PFS *)PFS9_BASE)
#define REG_PFSA    ( (volatile T_RA6_PFS *)PFSA_BASE)
#define REG_PFSB    ( (volatile T_RA6_PFS *)PFSB_BASE)

#define REG_SAR     ( (volatile T_RA6_SAR *)SAR_BASE)

#define REG_PFENET  (*(volatile UB *)PFENET_BASE)
#ifdef __BUILD_SECURE__
#define REG_PWPR    (*(volatile UB *)PWPRS_BASE)
#else
#define REG_PWPR    (*(volatile UB *)PWPR_BASE)
#endif

#elif defined(_DV_RA6M3_H_)
#define REG_PORT0   (*(volatile T_RA6_PORT *)PORT0_BASE)
#define REG_PORT1   (*(volatile T_RA6_PORT *)PORT1_BASE)
#define REG_PORT2   (*(volatile T_RA6_PORT *)PORT2_BASE)
#define REG_PORT3   (*(volatile T_RA6_PORT *)PORT3_BASE)
#define REG_PORT4   (*(volatile T_RA6_PORT *)PORT4_BASE)
#define REG_PORT5   (*(volatile T_RA6_PORT *)PORT5_BASE)
#define REG_PORT6   (*(volatile T_RA6_PORT *)PORT6_BASE)
#define REG_PORT7   (*(volatile T_RA6_PORT *)PORT7_BASE)
#define REG_PORT8   (*(volatile T_RA6_PORT *)PORT8_BASE)
#define REG_PORT9   (*(volatile T_RA6_PORT *)PORT9_BASE)
#define REG_PORTA   (*(volatile T_RA6_PORT *)PORTA_BASE)
#define REG_PORTB   (*(volatile T_RA6_PORT *)PORTB_BASE)

#define REG_PFS0    ( (volatile T_RA6_PFS *)PFS0_BASE)
#define REG_PFS1    ( (volatile T_RA6_PFS *)PFS1_BASE)
#define REG_PFS2    ( (volatile T_RA6_PFS *)PFS2_BASE)
#define REG_PFS3    ( (volatile T_RA6_PFS *)PFS3_BASE)
#define REG_PFS4    ( (volatile T_RA6_PFS *)PFS4_BASE)
#define REG_PFS5    ( (volatile T_RA6_PFS *)PFS5_BASE)
#define REG_PFS6    ( (volatile T_RA6_PFS *)PFS6_BASE)
#define REG_PFS7    ( (volatile T_RA6_PFS *)PFS7_BASE)
#define REG_PFS8    ( (volatile T_RA6_PFS *)PFS8_BASE)
#define REG_PFS9    ( (volatile T_RA6_PFS *)PFS9_BASE)
#define REG_PFSA    ( (volatile T_RA6_PFS *)PFSA_BASE)
#define REG_PFSB    ( (volatile T_RA6_PFS *)PFSB_BASE)

#define REG_PFENET  (*(volatile UB *)PFENET_BASE)
#define REG_PWPR    (*(volatile UB *)PWPR_BASE)

#elif defined(_DV_RA4M3_H_)
#define REG_PORT0   (*(volatile T_RA6_PORT *)PORT0_BASE)
#define REG_PORT1   (*(volatile T_RA6_PORT *)PORT1_BASE)
#define REG_PORT2   (*(volatile T_RA6_PORT *)PORT2_BASE)
#define REG_PORT3   (*(volatile T_RA6_PORT *)PORT3_BASE)
#define REG_PORT4   (*(volatile T_RA6_PORT *)PORT4_BASE)
#define REG_PORT5   (*(volatile T_RA6_PORT *)PORT5_BASE)
#define REG_PORT6   (*(volatile T_RA6_PORT *)PORT6_BASE)
#define REG_PORT7   (*(volatile T_RA6_PORT *)PORT7_BASE)
#define REG_PORT8   (*(volatile T_RA6_PORT *)PORT8_BASE)

#define REG_PFS0    ( (volatile T_RA6_PFS *)PFS0_BASE)
#define REG_PFS1    ( (volatile T_RA6_PFS *)PFS1_BASE)
#define REG_PFS2    ( (volatile T_RA6_PFS *)PFS2_BASE)
#define REG_PFS3    ( (volatile T_RA6_PFS *)PFS3_BASE)
#define REG_PFS4    ( (volatile T_RA6_PFS *)PFS4_BASE)
#define REG_PFS5    ( (volatile T_RA6_PFS *)PFS5_BASE)
#define REG_PFS6    ( (volatile T_RA6_PFS *)PFS6_BASE)
#define REG_PFS7    ( (volatile T_RA6_PFS *)PFS7_BASE)
#define REG_PFS8    ( (volatile T_RA6_PFS *)PFS8_BASE)

#define REG_SAR     ( (volatile T_RA6_SAR *)SAR_BASE)

#ifdef __BUILD_SECURE__
#define REG_PWPR    (*(volatile UB *)PWPRS_BASE)
#else
#define REG_PWPR    (*(volatile UB *)PWPR_BASE)
#endif

#endif


#ifdef __cplusplus
}
#endif
#endif /* _DV_RA6_PFS_PORT_H_ */
