/*
 *
 *           MULti Core Operating System - Multilayer Kernel
 *                      Device header for RA6 SYSC
 *
 *           Copyright (c) 2025 SPIRAL-TECH Co.,ltd All Rights Reserved.
 *
 *  File name       dv_ra6_sysc.h
 *
 *  Feb/02/2025     Created.
 *
 */

#ifndef _DV_RA6_SYSC_H_
#define _DV_RA6_SYSC_H_
#ifdef __cplusplus
extern "C" {
#endif

/* Base Address */

#define SYSC_BASE       0x4001E000      /* SYSC Base address */



/* Registers */

typedef struct {
    UW  reserved[3];
    UH  SBYCR;          /* Standby Control Register                            */
    UH  reserved1;
    UW  reserved2[3];
    UW  MSTPCRA;        /* Module Stop Control Register A                      */
    UW  SCKDIVCR;       /* System Clock Division Control Register              */
    UB  SCKDIVCR2;      /* System Clock Division Control Register 2            */
    UB  reserved3;
    UB  SCKSCR;         /* System Clock Source Control Register                */
    UB  reserved4;
    UH  PLLCCR;         /* PLL Clock Control Register                          */
    UB  PLLCR;          /* PLL Control Register                                */
    UB  PLLCCR2;        /* PLL Clock Control Register2                         */
    UW  reserved5;
    UB  BCKCR;          /* External Bus Clock Control Register                 */
    UB  MEMWAIT;        /* Memory Wait Cycle Control Register                  */
    UB  MOSCCR;         /* Main Clock Oscillator Control Register              */
    UB  reserved6;
    UH  reserved7;
    UB  HOCOCR;         /* High-Speed On-Chip Oscillator Control Register      */
    UB  HOCOCR2;        /* High-Speed On-Chip Oscillator Control Register 2    */
    UB  MOCOCR;         /* Middle-Speed On-Chip Oscillator Control Register    */
    UB  FLLCR1;         /* FLL Control Register 1                              */
    UH  FLLCR2;         /* FLL Control Register 2                              */
    UB  OSCSF;          /* Oscillation Stabilization Flag Register             */
    UB  reserved8;
    UB  CKOCR;          /* Clock Out Control Register                          */
    UB  TRCKCR;         /* Trace Clock Control Register                        */
    UB  OSTDCR;         /* Oscillation Stop Detection Control Register         */
    UB  OSTDSR;         /* Oscillation Stop Detection Status Register          */
    UH  reserved9;
    UW  reserved10;
    UH  PLL2CCR;        /* PLL2 Clock Control Register                         */
    UB  PLL2CR;         /* PLL2 Control Register                               */
    UB  reserved11;
    UB  LPOPT;          /* Lower Power Operation Control Register              */
    UB   reserved12;
    UH  reserved13;
    UB  SLCDSCKCR;      /* Segment LCD Source Clock Control Register           */
    UB  reserved14;
    UB  EBCKOCR;        /* External Bus Clock Output Control Register          */
    UB  SDCKOCR;        /* SDRAM Clock Output Control Register                 */
    UW  reserved15[3];
    UB  reserved16;
    UB  MOCOUTCR;       /* MOCO User Trimming Control Register                 */
    UB  HOCOUTCR;       /* HOCO User Trimming Control Register                 */
    UB  reserved17;
    UW  reserved18[2];
    UB  USBCKDIVCR;     /* USB Clock Division Control Register                 */
    union
    {
        UB  OCTACKDIVCR;/* Octal-SPI Clock Division Control Register           */
        UB  SCISPICKDIVCR;/* SCI SPI Clock Division Control Register           */
    };
    UB  CANFDCKDIVCR;   /* CANFD Clock Division Control Register               */
    union
    {
        UB  GPTCKDIVCR; /* GPT Clock Division Control Register                 */
        UB  USB60CKDIVCR; /* USB60 Clock Division Control Register             */
    };
    union
    {
        UB  CECCKDIVCR; /* CEC Clock Division Control Register                 */
        UB  IICCKDIVCR; /* IIC Clock Division Control Register                 */
    };
    UB  I3CCKDIVCR;     /* I3C clock Division control register                 */
    UH  reserved19;
    UB  USBCKCR;        /* USB Clock Control Register                          */
    union
    {
        UB  OCTACKCR;   /* Octal-SPI Clock Control Register                    */
        UB  SCISPICKCR; /* SCI SPI Clock Control Register                      */
    };
    UB  CANFDCKCR;      /* CANFD Clock Control Register                        */
    union
    {
        UB  GPTCKCR;    /* GPT Clock Control Register                          */
        UB  USB60CKCR;  /* USB60 clock control register                        */
    };
    union
    {
        UB  CECCKCR;    /* CEC Clock Control Register                          */
        UB  IICCKCR;    /* IIC Clock Control Register                          */
    };
    UB  I3CCKCR;        /* I3C Clock Control Register                          */
    UH  reserved20;
    UW  reserved21[3];
    UW  SNZREQCR1;      /* Snooze Request Control Register 1                   */
    UW  reserved22;
    UH  reserved23;
    UB  SNZCR;          /* Snooze Control Register                             */
    UB  reserved24;
    UB  SNZEDCR;        /* Snooze End Control Register                         */
    UB  SNZEDCR1;       /* Snooze End Control Register 1                       */
    UH  reserved25;
    UW  SNZREQCR;       /* Snooze Request Control Register                     */
    UH  reserved26;
    UB  FLSTOP;         /* Flash Operation Control Register                    */
    UB  PSMCR;          /* Power Save Memory Control Register                  */
    UB  OPCCR;          /* Operating Power Control Register                    */
    UB  reserved27;
    UB  MOSCWTCR;       /* Main Clock Oscillator Wait Control Register         */
    UB  reserved28[2];
    UB  HOCOWTCR;       /* High-speed on-chip oscillator wait control register */
    UH  reserved29[2];
    UB  SOPCCR;         /* Sub Operating Power Control Register                */
    UB  reserved30;
    UW  reserved31[5];
    UH  RSTSR1;         /* Reset Status Register 1                             */
    UH  reserved32;
    UW  reserved33[3];
    UB  USBCKCR_ALT;    /* USB Clock Control Register                          */
    UB  SDADCCKCR;      /* 24-bit Sigma-Delta A/D Converter Clock Control Register    */
    UH  reserved34;
    UW  reserved35[3];
    UB  LVD1CR1;        /* Voltage Monitor 1 Circuit Control Register 1        */
    UB  LVD1SR;         /* Voltage Monitor 1 Circuit Status Register           */
    UB  LVD2CR1;        /* Voltage Monitor 2 Circuit Control Register 1        */
    UB  LVD2SR;         /* Voltage Monitor 2 Circuit Status Register           */
    UW  reserved36[183];
    UW  CGFSAR;         /* Clock Generation Function Security Attribute Register */
    UW  reserved37;
    UW  LPMSAR;         /* Low Power Mode Security Attribution Register        */
    union
    {
        UW  LVDSAR;     /* Low Voltage Detection Security Attribution Register */
        UW  RSTSAR;     /* Reset Security Attribution Register                 */
    };
    UW  BBFSAR;         /* Battery Backup Function Security Attribute Register */
    UW  reserved38[3];
    UW  DPFSAR;         /* Deep Standby Interrupt Factor Security Attribution Register  */
    UW  reserved39[6];
    UH  reserved40;
    UH  PRCR;           /* Protect Register                                    */
    UB  DPSBYCR;        /* Deep Standby Control Register                       */
    UB  DPSWCR;         /* Deep Standby Wait Control Register                  */
    UB  DPSIER0;        /* Deep Standby Interrupt Enable Register 0            */
    UB  DPSIER1;        /* Deep Standby Interrupt Enable Register 1            */
    UB  DPSIER2;        /* Deep Standby Interrupt Enable Register 2            */
    UB  DPSIER3;        /* Deep Standby Interrupt Enable Register 3            */
    UB  DPSIFR0;        /* Deep Standby Interrupt Flag Register 0              */
    UB  DPSIFR1;        /* Deep Standby Interrupt Flag Register 1              */
    UB  DPSIFR2;        /* Deep Standby Interrupt Flag Register 2              */
    UB  DPSIFR3;        /* Deep Standby Interrupt Flag Register 3              */
    UB  DPSIEGR0;       /* Deep Standby Interrupt Edge Register 0              */
    UB  DPSIEGR1;       /* Deep Standby Interrupt Edge Register 1              */
    UB  DPSIEGR2;       /* Deep Standby Interrupt Edge Register 2              */
    UB  reserved41;
    UB  SYOCDCR;        /* System Control OCD Control Register                 */
    UB  STCONR;         /* Standby Condition Register                          */
    UB  RSTSR0;         /* Reset Status Register 0                             */
    UB  RSTSR2;         /* Reset Status Register 2                             */
    UB  reserved42;
    UB  MOMCR;          /* Main Clock Oscillator Mode Oscillation Control Register */
    UH  reserved43;
    UB  FWEPROR;        /* Flash P/E Protect Register                          */
    union
    {
        UB  LVCMPCR;    /* Voltage Monitor Circuit Control Register            */
        UB  LVD1CMPCR;  /* Voltage Monitoring 1 Comparator Control Register    */
    };
    union
    {
        UB  LVDLVLR;    /* Voltage Detection Level Select Register             */
        UB  LVD2CMPCR;  /* Voltage Monitoring 2 Comparator Control Register    */
    };
    UB  reserved44;
    UB  LVD1CR0;        /* Voltage Monitor 1 Circuit Control Register 0        */
    UB  LVD2CR0;        /* Voltage Monitor 2 Circuit Control Register 0        */
    UB  reserved45;
    UB  VBATTMNSELR;    /* Battery Backup Voltage Monitor Function Select Register */
    UB  VBATTMONR;      /* Battery Backup Voltage Monitor Register             */
    UB  VBTCR1;         /* VBATT Control Register1                             */
    UW  reserved46[8];
    union
    {
        UB  DCDCCTL;    /* DCDC/LDO Control Register                           */
        UB  LDOSCR;     /* LDO Stop Control Register                           */
    };
    UB  VCCSEL;         /* Voltage Level Selection Control Register            */
    UH  reserved47;
    UB  PL2LDOSCR;      /* PLL2-LDO Stop Control Register                      */
    UB  reserved48;
    UH  reserved49;
    UW  reserved50[14];
    UB  SOSCCR;         /* Sub-Clock Oscillator Control Register               */
    UB  SOMCR;          /* Sub Clock Oscillator Mode Control Register          */
    UB  SOMRG;          /* Sub Clock Oscillator Margin Check Register          */
    UB   reserved51;
    UW  reserved52[3];
    UB  LOCOCR;         /* Low-Speed On-Chip Oscillator Control Register       */
    UB  reserved53;
    UB  LOCOUTCR;       /* LOCO User Trimming Control Register                 */
    UB  reserved54;
    UW  reserved55[7];
    UB  VBTCR2;         /* VBATT Control Register 2                            */
    UB  VBTSR;          /* VBATT Status Register                               */
    UB  VBTCMPCR;       /* VBATT Comparator Control Register                   */
    UB  reserved56;
    UB  VBTLVDICR;      /* VBATT Pin Low Voltage Detect Interrupt Control Register */
    UB  reserved57;
    UB  VBTWCTLR;       /* VBATT Wakeup function Control Register              */
    UB  reserved58;
    UB  VBTWCH0OTSR;    /* VBATT Wakeup I/O 0 Output Trigger Select Register   */
    UB  VBTWCH1OTSR;    /* VBATT Wakeup I/O 1 Output Trigger Select Register   */
    UB  VBTWCH2OTSR;    /* VBATT Wakeup I/O 2 Output Trigger Select Register   */
    UB  VBTICTLR;       /* VBATT Input Control Register                        */
    UB  VBTOCTLR;       /* VBATT Output Control Register                       */
    UB  VBTWTER;        /* VBATT Wakeup Trigger source Enable Register         */
    UB  VBTWEGR;        /* VBATT Wakeup Trigger source Edge Register           */
    UB  VBTWFR;         /* VBATT Wakeup trigger source Flag Register           */
    UB  VBTBER;         /* VBATT Backup Enable Register                        */
    UB  reserved59;
    UH  reserved60;
    UW  reserved61[15];
    UB  VBTBKR[512];    /* VBATT Backup Register [0..511]                      */
} T_RA6_SYSC; 


/* Port access structure */

#define REG_SYSC    (*(volatile T_RA6_SYSC *)SYSC_BASE)


#ifdef __cplusplus
}
#endif
#endif /* _DV_RA6_SYSC_H_ */
